# The Tabulation Package

This package contains functions to define and read a schema file. A schema is a user-defined structure, for one or more tables, that maps a FHIR resource and element to a specified column in a table.